==> lime-etl-0.1.0.tar.gz: lime-etl-0.1.0/lime_etl/domain/job_spec.py <==
from __future__ import annotations

import abc

import typing

from domain import job_test_result, value_objects  # type: ignore
from services import job_logging_service, unit_of_work  # type: ignore


class JobSpec(abc.ABC):
    @property
    @abc.abstractmethod
    def dependencies(self) -> typing.List[JobSpec]:
        raise NotImplementedError

    @property
    @abc.abstractmethod
    def job_name(self) -> value_objects.JobName:
        raise NotImplementedError

    @property
    @abc.abstractmethod
    def seconds_between_refreshes(self) -> value_objects.SecondsBetweenRefreshes:
        raise NotImplementedError

    @property
    @abc.abstractmethod
    def timeout_seconds(self) -> value_objects.TimeoutSeconds:
        raise NotImplementedError

    @property
    @abc.abstractmethod
    def max_retries(self) -> value_objects.MaxRetries:
        raise NotImplementedError


class AdminJobSpec(JobSpec):
    @abc.abstractmethod
    def run(
        self,
        uow: unit_of_work.UnitOfWork,
        logger: job_logging_service.JobLoggingService,
    ) -> value_objects.Result:
        raise NotImplementedError

    @abc.abstractmethod
    def test(
        self,
        uow: unit_of_work.UnitOfWork,
        logger: job_logging_service.JobLoggingService,
    ) -> typing.Collection[job_test_result.SimpleJobTestResult]:
        raise NotImplementedError


class ETLJobSpec(JobSpec):
    @abc.abstractmethod
    def run(
        self, logger: job_logging_service.JobLoggingService
    ) -> value_objects.Result:
        raise NotImplementedError

    @abc.abstractmethod
    def test(
        self, logger: job_logging_service.JobLoggingService
    ) -> typing.Collection[job_test_result.SimpleJobTestResult]:
        raise NotImplementedError

==> lime-etl-0.1.13.tar.gz: lime-etl-0.1.13/lime_etl/domain/job_spec.py <==
from __future__ import annotations

import abc
import typing

from lime_etl.domain import job_test_result, value_objects
from lime_etl.services import job_logging_service, unit_of_work


class JobSpec(abc.ABC):
    @property
    @abc.abstractmethod
    def dependencies(self) -> typing.List[value_objects.JobName]:
        raise NotImplementedError

    @property
    @abc.abstractmethod
    def job_name(self) -> value_objects.JobName:
        raise NotImplementedError

    @property
    @abc.abstractmethod
    def max_retries(self) -> value_objects.MaxRetries:
        raise NotImplementedError

    @abc.abstractmethod
    def on_execution_error(self, error_message: str) -> typing.Optional[JobSpec]:
        raise NotImplementedError

    @abc.abstractmethod
    def on_test_failure(
        self, test_results: typing.FrozenSet[job_test_result.JobTestResult]
    ) -> typing.Optional[JobSpec]:
        raise NotImplementedError

    @property
    @abc.abstractmethod
    def seconds_between_refreshes(self) -> value_objects.SecondsBetweenRefreshes:
        raise NotImplementedError

    @property
    @abc.abstractmethod
    def timeout_seconds(self) -> value_objects.TimeoutSeconds:
        raise NotImplementedError


class AdminJobSpec(JobSpec):
    @abc.abstractmethod
    def on_execution_error(self, error_message: str) -> typing.Optional[AdminJobSpec]:
        raise NotImplementedError

    @abc.abstractmethod
    def on_test_failure(
        self, test_results: typing.FrozenSet[job_test_result.JobTestResult]
    ) -> typing.Optional[AdminJobSpec]:
        raise NotImplementedError

    @abc.abstractmethod
    def run(
        self,
        uow: unit_of_work.UnitOfWork,
        logger: job_logging_service.JobLoggingService,
    ) -> value_objects.Result:
        raise NotImplementedError

    @abc.abstractmethod
    def test(
        self,
        uow: unit_of_work.UnitOfWork,
        logger: job_logging_service.JobLoggingService,
    ) -> typing.Collection[job_test_result.SimpleJobTestResult]:
        raise NotImplementedError


class ETLJobSpec(JobSpec):
    @abc.abstractmethod
    def on_execution_error(self, error_message: str) -> typing.Optional[ETLJobSpec]:
        raise NotImplementedError

    @abc.abstractmethod
    def on_test_failure(
        self, test_results: typing.FrozenSet[job_test_result.JobTestResult]
    ) -> typing.Optional[ETLJobSpec]:
        raise NotImplementedError

    @property
    @abc.abstractmethod
    def resources_needed(
        self,
    ) -> typing.Collection[value_objects.ResourceName]:
        raise NotImplementedError

    @abc.abstractmethod
    def run(
        self,
        logger: job_logging_service.JobLoggingService,
        resources: typing.Mapping[value_objects.ResourceName, typing.Any],
    ) -> value_objects.Result:
        raise NotImplementedError

    @abc.abstractmethod
    def test(
        self,
        logger: job_logging_service.JobLoggingService,
        resources: typing.Mapping[value_objects.ResourceName, typing.Any],
    ) -> typing.Collection[job_test_result.SimpleJobTestResult]:
        raise NotImplementedError
